aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org/apache/fop/render/afp/fonts
diff options
context:
space:
mode:
authorAdrian Cumiskey <acumiskey@apache.org>2007-12-05 17:28:48 +0000
committerAdrian Cumiskey <acumiskey@apache.org>2007-12-05 17:28:48 +0000
commit4ea954df52f2a4aa8a20cd64c9660c0da617a71a (patch)
treee6addf802243190e1b79e79b9000b14b1c320ffd /src/java/org/apache/fop/render/afp/fonts
parentc278c99ef16c18bf9243432ae706e1bf1adb3393 (diff)
downloadxmlgraphics-fop-4ea954df52f2a4aa8a20cd64c9660c0da617a71a.tar.gz
xmlgraphics-fop-4ea954df52f2a4aa8a20cd64c9660c0da617a71a.zip
Checkstyle fixes
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@601431 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org/apache/fop/render/afp/fonts')
-rw-r--r--src/java/org/apache/fop/render/afp/fonts/FopCharacterSet.java27
1 files changed, 14 insertions, 13 deletions
diff --git a/src/java/org/apache/fop/render/afp/fonts/FopCharacterSet.java b/src/java/org/apache/fop/render/afp/fonts/FopCharacterSet.java
index 67cd5b266..cde2c141d 100644
--- a/src/java/org/apache/fop/render/afp/fonts/FopCharacterSet.java
+++ b/src/java/org/apache/fop/render/afp/fonts/FopCharacterSet.java
@@ -27,8 +27,8 @@ import org.apache.fop.fonts.Typeface;
public class FopCharacterSet extends CharacterSet {
/** The character set for this font */
- private Typeface _characterSet = null;
- private int _size = 0;
+ private Typeface charSet = null;
+ private int size = 0;
/**
* Constructor for the CharacterSetMetric object, the character set is used
@@ -37,17 +37,18 @@ public class FopCharacterSet extends CharacterSet {
* @param encoding the encoding of the font
* @param name the character set name
* @param size the font size
* @param characterSet the fop character set
*/
public FopCharacterSet(
String codePage,
String encoding,
String name,
int size,
- Typeface characterSet) {
+ Typeface charSet) {
+
super(codePage, encoding, name, null);
- _characterSet = characterSet;
- _size = size * 1000;
+ this.charSet = charSet;
+ this.size = size * 1000;
}
/**
@@ -63,7 +64,7 @@ public class FopCharacterSet extends CharacterSet {
* @return the ascender value in millipoints
*/
public int getAscender() {
- return _characterSet.getAscender(_size);
+ return charSet.getAscender(size);
}
/**
@@ -73,7 +74,7 @@ public class FopCharacterSet extends CharacterSet {
* @return the cap height value in millipoints
*/
public int getCapHeight() {
- return _characterSet.getCapHeight(_size);
+ return charSet.getCapHeight(size);
}
/**
@@ -83,7 +84,7 @@ public class FopCharacterSet extends CharacterSet {
* @return the descender value in millipoints
*/
public int getDescender() {
- return _characterSet.getDescender(_size);
+ return charSet.getDescender(size);
}
/**
@@ -107,7 +108,7 @@ public class FopCharacterSet extends CharacterSet {
* @return the widths of all characters
*/
public int[] getWidths() {
- return _characterSet.getWidths();
+ return charSet.getWidths();
}
/**
@@ -115,7 +116,7 @@ public class FopCharacterSet extends CharacterSet {
* @return the typical height of characters
*/
public int getXHeight() {
- return _characterSet.getXHeight(_size);
+ return charSet.getXHeight(size);
}
/**
@@ -125,7 +126,7 @@ public class FopCharacterSet extends CharacterSet {
* @return the width of the character
*/
public int width(int character) {
- return _characterSet.getWidth(character, _size);
+ return charSet.getWidth(character, size);
}
/**
@@ -134,7 +135,7 @@ public class FopCharacterSet extends CharacterSet {
* @return the mapped character
*/
public char mapChar(char c) {
- return _characterSet.mapChar(c);
+ return charSet.mapChar(c);
}
} \ No newline at end of file
@@ -37,17 +37,18 @@ public class FopCharacterSet extends CharacterSet {
* @param name the character set name
* @param size the font size
- * @param characterSet the fop character set
+ * @param charSet the fop character set
*/
public FopCharacterSet(